// generators.h

#ifndef _GENERATORS_H
#define _GENERATORS_H

class TextGenerator;
class CharTranslator;

extern TextGenerator *GlobalGenerator ;
extern TextGenerator *NormalGenerator ;
extern TextGenerator *KeywordGenerator ;
extern TextGenerator *CommentGenerator ;
extern TextGenerator *StringGenerator ;
extern TextGenerator *TypeGenerator ;
extern TextGenerator *NumberGenerator ;
extern TextGenerator *PreProcGenerator ;
extern TextGenerator *SymbolGenerator ;
extern TextGenerator *FunctionGenerator ;
extern TextGenerator *CBracketGenerator ;

extern void createGenerators(CharTranslator *, int) ;
extern void createGeneratorsForCSS(CharTranslator *, int) ;

#endif
